@@ -1,7 +1,5 @@
-function isAbsolute() {
-}
+function isAbsolute() {}
 function parse(path__2) {
     const isAbsolute__2 = path__2.charCodeAt(0) === CHAR_FORWARD_SLASH;
-    if (isAbsolute__2) {
-    }
+    if (isAbsolute__2) {}
 }
